@@ -40,6 +40,7 @@ const (
 	HubKeyPluginConfig HubKey = "plugin_config"
 	HubKeyProto        HubKey = "proto"
 	HubKeyStreamRoute  HubKey = "stream_route"
+	HubKeySystemConfig HubKey = "system_config"
 )
 
 var (
@@ -48,14 +49,16 @@ var (
 
 func InitStore(key HubKey, opt GenericStoreOption) error {
 	hubsNeedCheck := map[HubKey]bool{
-		HubKeyConsumer:    true,
-		HubKeyRoute:       true,
-		HubKeySsl:         true,
-		HubKeyService:     true,
-		HubKeyUpstream:    true,
-		HubKeyGlobalRule:  true,
-		HubKeyStreamRoute: true,
+		HubKeyConsumer:     true,
+		HubKeyRoute:        true,
+		HubKeySsl:          true,
+		HubKeyService:      true,
+		HubKeyUpstream:     true,
+		HubKeyGlobalRule:   true,
+		HubKeyStreamRoute:  true,
+		HubKeySystemConfig: true,
 	}
+
 	if _, ok := hubsNeedCheck[key]; ok {
 		validator, err := NewAPISIXJsonSchemaValidator("main." + string(key))
 		if err != nil {
@@ -229,5 +232,17 @@ func InitStores() error {
 		return err
 	}
 
+	err = InitStore(HubKeySystemConfig, GenericStoreOption{
+		BasePath: conf.ETCDConfig.Prefix + "/system_config",
+		ObjType:  reflect.TypeOf(entity.SystemConfig{}),
+		KeyFunc: func(obj interface{}) string {
+			r := obj.(*entity.SystemConfig)
+			return r.ConfigName
+		},
+	})
+	if err != nil {
+		return err
+	}
+
 	return nil
 }
