@@ -30,7 +30,7 @@ export default {
   'component.plugin.serverless': '无服务器架构',
   'component.plugin.observability': '可观测性',
   'component.plugin.other': '其它',
-
+  'component.plugin.all': '所有',
   // cors
   'component.pluginForm.cors.allow_origins.tooltip':
     '允许跨域访问的 Origin，格式如：scheme://host:port，比如: https://somehost.com:8081 。多个值使用 , 分割，allow_credential 为 false 时可以使用 * 来表示所有 Origin 均允许通过。你也可以在启用了 allow_credential 后使用 ** 强制允许所有 Origin 都通过，但请注意这样存在安全隐患。',
@@ -62,6 +62,8 @@ export default {
 
   // api-breaker
   'component.pluginForm.api-breaker.break_response_code.tooltip': '不健康返回错误码。',
+  'component.pluginForm.api-breaker.break_response_body.tooltip': '不健康返回报文',
+  'component.pluginForm.api-breaker.break_response_headers.tooltip': '不健康返回报文头',
   'component.pluginForm.api-breaker.max_breaker_sec.tooltip': '最大熔断持续时间。',
   'component.pluginForm.api-breaker.unhealthy.http_statuses.tooltip': '不健康时候的状态码。',
   'component.pluginForm.api-breaker.unhealthy.failures.tooltip':
