@@ -19,4 +19,6 @@ export default {
   'page.plugin.list': '插件列表',
   'page.plugin.list.enabled': '已启用插件的列表',
   'page.plugin.market.config': '全局插件列表',
+  'page.plugin.edit': '配置插件成功',
+  'page.plugin.delete': '删除插件成功',
 };
